@@ -7,11 +7,17 @@ pyOpenSSL - A simple wrapper around the OpenSSL library
 """
 
 __all__ = [
-    "__author__", "__copyright__", "__email__", "__license__", "__summary__",
-    "__title__", "__uri__", "__version__",
+    "__author__",
+    "__copyright__",
+    "__email__",
+    "__license__",
+    "__summary__",
+    "__title__",
+    "__uri__",
+    "__version__",
 ]
 
-__version__ = "19.1.0"
+__version__ = "22.1.0"
 
 __title__ = "pyOpenSSL"
 __uri__ = "https://pyopenssl.org/"
@@ -19,4 +25,4 @@ __summary__ = "Python wrapper module around the OpenSSL library"
 __author__ = "The pyOpenSSL developers"
 __email__ = "cryptography-dev@python.org"
 __license__ = "Apache License, Version 2.0"
-__copyright__ = "Copyright 2001-2017 {0}".format(__author__)
+__copyright__ = "Copyright 2001-2022 {0}".format(__author__)
